pub struct ElasticSearchConfig {
phantom_use: Option<String>,
pub id: String,
pub address: String,
pub port: u16,
pub user: String,
pub password: String,
pub image: String,
pub user_managed: bool,
pub persist_data: bool,
}Fields
phantom_use: Option<String>id: Stringaddress: Stringport: u16user: Stringpassword: Stringimage: Stringuser_managed: boolpersist_data: boolTrait Implementations
Sourceimpl Clone for ElasticSearchConfig
impl Clone for ElasticSearchConfig
Sourcefn clone(&self) -> ElasticSearchConfig
fn clone(&self) -> ElasticSearchConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ElasticSearchConfig
impl Debug for ElasticSearchConfig
Sourceimpl<'de> Deserialize<'de> for ElasticSearchConfig
impl<'de> Deserialize<'de> for ElasticSearchConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DockerServiceConfig for ElasticSearchConfig
impl DockerServiceConfig for ElasticSearchConfig
Sourcefn is_user_managed(&self) -> bool
fn is_user_managed(&self) -> bool
Whether the service is managed by the user. Read more
Sourcefn envs(&self) -> Vec<(String, String)>
fn envs(&self) -> Vec<(String, String)>
The environment variables to pass to the docker container.
Sourcefn ports(&self) -> Vec<(String, String)>
fn ports(&self) -> Vec<(String, String)>
The ports to expose on the host, e.g.
("0.0.0.0:23306", "3306"). Read moreSourcefn data_path(&self) -> Option<String>
fn data_path(&self) -> Option<String>
The path in the container to persist data to, e.g.
/var/lib/mysql. Read moreSourcefn latency_ms(&self) -> u32
fn latency_ms(&self) -> u32
Network latency in milliseconds to add to the container. Read more
Sourceimpl PartialEq for ElasticSearchConfig
impl PartialEq for ElasticSearchConfig
Sourcefn eq(&self, other: &ElasticSearchConfig) -> bool
fn eq(&self, other: &ElasticSearchConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ElasticSearchConfig
impl Serialize for ElasticSearchConfig
impl StructuralPartialEq for ElasticSearchConfig