pub struct NatsConfig {
phantom_use: Option<String>,
pub id: String,
pub address: String,
pub port: u16,
pub monitor_port: u16,
pub image: String,
pub user_managed: bool,
pub persist_data: bool,
}Fields
phantom_use: Option<String>id: Stringaddress: Stringport: u16monitor_port: u16image: Stringuser_managed: boolpersist_data: boolTrait Implementations
Sourceimpl Clone for NatsConfig
impl Clone for NatsConfig
Sourcefn clone(&self) -> NatsConfig
fn clone(&self) -> NatsConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NatsConfig
impl Debug for NatsConfig
Sourceimpl<'de> Deserialize<'de> for NatsConfig
impl<'de> Deserialize<'de> for NatsConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DockerServiceConfig for NatsConfig
impl DockerServiceConfig for NatsConfig
Sourcefn is_user_managed(&self) -> bool
fn is_user_managed(&self) -> bool
Whether the service is managed by the user. Read more
Sourcefn ports(&self) -> Vec<(String, String)>
fn ports(&self) -> Vec<(String, String)>
The ports to expose on the host, e.g.
("0.0.0.0:23306", "3306"). Read moreSourcefn data_path(&self) -> Option<String>
fn data_path(&self) -> Option<String>
The path in the container to persist data to, e.g.
/var/lib/mysql. Read moreSourcefn envs(&self) -> Vec<(String, String)>
fn envs(&self) -> Vec<(String, String)>
The environment variables to pass to the docker container.
Sourcefn latency_ms(&self) -> u32
fn latency_ms(&self) -> u32
Network latency in milliseconds to add to the container. Read more
Sourceimpl PartialEq for NatsConfig
impl PartialEq for NatsConfig
Sourceimpl Serialize for NatsConfig
impl Serialize for NatsConfig
impl StructuralPartialEq for NatsConfig