pub struct OpenSearchConfig {
phantom_use: Option<String>,
pub id: String,
pub address: String,
pub port: u16,
pub user: String,
pub password: String,
pub image: String,
pub user_managed: bool,
pub persist_data: bool,
}Fields
phantom_use: Option<String>id: Stringaddress: Stringport: u16user: Stringpassword: Stringimage: Stringuser_managed: boolpersist_data: boolTrait Implementations
Sourceimpl Clone for OpenSearchConfig
impl Clone for OpenSearchConfig
Sourcefn clone(&self) -> OpenSearchConfig
fn clone(&self) -> OpenSearchConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OpenSearchConfig
impl Debug for OpenSearchConfig
Sourceimpl<'de> Deserialize<'de> for OpenSearchConfig
impl<'de> Deserialize<'de> for OpenSearchConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DockerServiceConfig for OpenSearchConfig
impl DockerServiceConfig for OpenSearchConfig
Sourcefn is_user_managed(&self) -> bool
fn is_user_managed(&self) -> bool
Whether the service is managed by the user. Read more
Sourcefn envs(&self) -> Vec<(String, String)>
fn envs(&self) -> Vec<(String, String)>
The environment variables to pass to the docker container.
Sourcefn ports(&self) -> Vec<(String, String)>
fn ports(&self) -> Vec<(String, String)>
The ports to expose on the host, e.g.
("0.0.0.0:23306", "3306"). Read moreSourcefn data_path(&self) -> Option<String>
fn data_path(&self) -> Option<String>
The path in the container to persist data to, e.g.
/var/lib/mysql. Read moreSourcefn latency_ms(&self) -> u32
fn latency_ms(&self) -> u32
Network latency in milliseconds to add to the container. Read more
Sourceimpl PartialEq for OpenSearchConfig
impl PartialEq for OpenSearchConfig
Sourcefn eq(&self, other: &OpenSearchConfig) -> bool
fn eq(&self, other: &OpenSearchConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for OpenSearchConfig
impl Serialize for OpenSearchConfig
impl StructuralPartialEq for OpenSearchConfig