pub struct PubsubConfig {
phantom_use: Option<String>,
pub id: String,
pub user_managed: bool,
pub image: String,
pub port: u16,
pub address: String,
pub persist_data: bool,
}Fields
phantom_use: Option<String>id: Stringuser_managed: boolimage: Stringport: u16address: Stringpersist_data: boolTrait Implementations
Sourceimpl Clone for PubsubConfig
impl Clone for PubsubConfig
Sourcefn clone(&self) -> PubsubConfig
fn clone(&self) -> PubsubConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PubsubConfig
impl Debug for PubsubConfig
Sourceimpl<'de> Deserialize<'de> for PubsubConfig
impl<'de> Deserialize<'de> for PubsubConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DockerServiceConfig for PubsubConfig
impl DockerServiceConfig for PubsubConfig
Sourcefn is_user_managed(&self) -> bool
fn is_user_managed(&self) -> bool
Whether the service is managed by the user. Read more
Sourcefn ports(&self) -> Vec<(String, String)>
fn ports(&self) -> Vec<(String, String)>
The ports to expose on the host, e.g.
("0.0.0.0:23306", "3306"). Read moreSourcefn envs(&self) -> Vec<(String, String)>
fn envs(&self) -> Vec<(String, String)>
The environment variables to pass to the docker container.
Sourcefn data_path(&self) -> Option<String>
fn data_path(&self) -> Option<String>
The path in the container to persist data to, e.g.
/var/lib/mysql. Read moreSourcefn latency_ms(&self) -> u32
fn latency_ms(&self) -> u32
Network latency in milliseconds to add to the container. Read more
Sourceimpl PartialEq for PubsubConfig
impl PartialEq for PubsubConfig
Sourcefn eq(&self, other: &PubsubConfig) -> bool
fn eq(&self, other: &PubsubConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PubsubConfig
impl Serialize for PubsubConfig
impl StructuralPartialEq for PubsubConfig